import {Component, OnInit} from '@angular/core';
import {NzMessageService} from 'ng-zorro-antd';
import {ModalHelper} from '@delon/theme';
import {HttpClient} from '@angular/common/http';
import {UserInstallerEditComponent} from './edit/edit.component';
import {environment} from  'environments/environment';
import {DateService} from '@business/services/util/date.service';

@Component({
  selector: 'app-installer',
  templateUrl: './installer.component.html',
  styles: []
})
export class InstallerComponent implements OnInit {

  q: any = {
    pi: 1,
    ps: 10,
    sorter: '',
    u_name: '',
    u_mobile: ''
  };
  data: any[] = [];
  total: 0;

  selectedRows: any[] = [];
  curRows: any[] = [];
  allChecked = false;
  indeterminate = false;
  sortMap: any = {};
  loading: boolean = true;

  constructor(
    public http: HttpClient,
    public dateSrv: DateService,
    public msgSrv: NzMessageService,
    private modalHelper: ModalHelper) {}

  ngOnInit() {
    this.load();
  }

  load(reload: boolean = false) {
    if (reload) {
      this.q.pi = 1;
    }
    this.http.get(environment.SERVER_BASH_URL + '/operateUser/list', {params: this.q}).subscribe((res: any) => {
      this.data = res.data.data;
      this.total = res.data.total;
      this.dataChange(this.data);
      this.loading = false;
    });
  }

  edit(user) {
    this.modalHelper.static(UserInstallerEditComponent, {user}).subscribe(() => {
      this.load(true);
      this.msgSrv.success('安装用户修改成功！');
    });
  }

  add() {
    const user = {};
    this.modalHelper.static(UserInstallerEditComponent, {user}).subscribe(() => {
      this.load(true);
      this.msgSrv.success('安装用户保存成功！');
    });
  }

  delete(user) {
    this.http.post(environment.SERVER_BASH_URL + '/operateUser/operateUser/id', user).subscribe((res: any) => {
      this.msgSrv.success('安装用户删除成功！');
      this.load(true);
    });
  }

  remove() {
    const ids = [];
    this.selectedRows.forEach(i => {
      ids.push(i.id);
    });
    this.http.post(environment.SERVER_BASH_URL + '/operateUser/operateUsers/ids', ids).subscribe((res: any) => {
      this.msgSrv.success('安装用户删除成功！');
      this.load(true);
    });
  }

  checkAll(value: boolean) {
    this.curRows.forEach(i => {
      if (i.isDelete == '1') {
        i.checked = false;
      } else {
        i.checked = value;
      }
    });
    this.refreshStatus();
  }

  dataChange(res: any) {
    this.curRows = res;
    this.refreshStatus();
  }

  refreshStatus() {
    const allChecked = this.curRows.every(value => value.checked);
    const allUnChecked = this.curRows.every(value => !value.checked);
    this.allChecked = allChecked;
    this.indeterminate = (!allChecked) && (!allUnChecked);
    this.selectedRows = this.data.filter(value => value.checked);
  }

  sort(field: string, value: any) {
    this.sortMap = {};
    this.sortMap[field] = value;
    this.q.sorter = value ? `${field} ${value}` : '';
    this.load(true);
  }

  reset(ls: any[]) {
    for (const item of ls) item.value = false;
    this.load(true);
  }

  format_date(date) {
    if (date) {
      return this.dateSrv.date_format(date, 'YYYY-MM-DD');
    }
  }
}
